/*-- 

 Copyright (C) 2001 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "JPublish" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "JPublish", nor
    may "JPublish" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on JPublish, please see <http://www.jpublish.org/>.
 
 */

package org.jpublish.repository.filesystem;

import java.io.File;
import java.io.FileInputStream;
import java.io.StringWriter;

import org.jdom.Element;

import org.apache.log4j.Category;

import org.apache.velocity.VelocityContext;
import org.apache.velocity.app.Velocity;

import org.jpublish.Repository;
import org.jpublish.Configurable;

public class FileSystemRepository implements Repository, Configurable{

	public String get(String path) throws Exception{
		log.debug("Getting static content element.");
		return loadContent(path);
	}

	public String get(String path, VelocityContext context) throws Exception{
		log.debug("Getting dynamic content element for path " + path);
		StringWriter writer = new StringWriter();
		File file = new File(root, path);
		Velocity.evaluate(context, writer, path, new FileInputStream(file));
		return writer.toString();
	}
	
	public String getName(){
		return name;
	}
	
	public long getLastModified(String path){
		return pathToFile(path).lastModified();
	}
	
	public String getRoot(){
		return root;
	}
	
	public void setRoot(String root){
		this.root = root;
	}
	
	public void loadConfiguration(Element element) throws Exception{
		this.name = element.getAttributeValue("name");
		setRoot(element.getChildTextTrim("root"));
	}
	
	private String loadContent(String path){
		File file = pathToFile(path);
		StringBuffer buffer = new StringBuffer();
		
		try{
			FileInputStream in = new FileInputStream(file);
			
			int c = -1;
			while((c = in.read()) != -1){
				buffer.append((char)c);
			}
		} catch(Exception e){
			buffer.append(e.getMessage());
		}
		
		return buffer.toString();
	}
	
	private File pathToFile(String path){
		return new File(root, path);
	}
	
	private static Category log = Category.getInstance(FileSystemRepository.class.getName());
	
	private String root;
	private String name;

}
