/*-- 

 Copyright (C) 2001 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "JPublish" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "JPublish", nor
    may "JPublish" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on JPublish, please see <http://www.jpublish.org/>.
 
 */

package org.jpublish.util;

import java.io.File;

import org.apache.log4j.Category;

import org.jpublish.Reloadable;

public class FileMonitor implements Runnable{

	public FileMonitor(File file, Reloadable target){
		this(file, DEFAULT_DELAY, target);
	}

	public FileMonitor(File file, long delay, Reloadable target){
		this.file = file;
		this.delay = delay;
		this.target = target;
		
		lastModified = file.lastModified();
	}
	
	public void startMonitor(){
		log.debug("Starting FileMonitor");
	
		running = true;
		thread = new Thread(this);
		thread.start();
	}
	
	public void stopMonitor(){
		log.debug("Stopping FileMonitor");
	
		running = false;
		thread.interrupt();
	}
	
	public File getFile(){
		return file;
	}
	
	public long getDelay(){
		return delay;
	}
	
	public void setDelay(long delay){
		this.delay = delay;
	}
	
	public void run(){
		log.debug("FileMonitor running.");
		while(running){
			try{
				Thread.sleep(delay);
			} catch(InterruptedException e){
				// do nothing
			}
			
			long currentLastModified = file.lastModified();
			if(currentLastModified != lastModified){
				log.info("Reloading " + file);
				target.reload();
				lastModified = currentLastModified;
			}
		}
		log.debug("FileMonitor stopped.");
	}
	
	/**	The default delay value (5 seconds) for checking for modifications. */
	public static final int DEFAULT_DELAY = 5000;
	
	private static Category log = Category.getInstance(FileMonitor.class.getName());
	
	private File file;
	private long delay;
	private Reloadable target;
	private long lastModified;
	
	private Thread thread;
	private boolean running = false;

}
