/*-- 

 Copyright (C) 2000 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The names "J/Top" and "JTop" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "J/Top" or "JTop", nor
    may "J/Top" or "JTop" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by the
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on J/Top, please see <http://www.anthonyeden.com/projects/jtop>.
 
 */

package com.anthonyeden.jtop;

import java.awt.Component;
import javax.swing.*;
import javax.swing.tree.*;
import com.anthonyeden.jtop.sentry.*;

public class HostTreeCellRenderer extends DefaultTreeCellRenderer{

	public HostTreeCellRenderer(){
		openFolderIcon = new ImageIcon("../images/Open.gif");
		closedFolderIcon = new ImageIcon("../images/Folder.gif");
		hostIcon = new ImageIcon("../images/World.gif");
		trafficOffIcon = new ImageIcon("../images/TrafficOff.gif");
		trafficGreenIcon = new ImageIcon("../images/TrafficGreen.gif");
		trafficRedIcon = new ImageIcon("../images/TrafficRed.gif");
		clockIcon = new ImageIcon("../images/Clock.gif");
	}

	public Component getTreeCellRendererComponent(JTree source, Object value, 
	boolean selected, boolean expanded, boolean leaf, int row, boolean hasFocus){
		
		super.getTreeCellRendererComponent(source, value, selected, expanded, leaf, row,
			hasFocus);
			
		DefaultMutableTreeNode node = (DefaultMutableTreeNode)value;
		Object userObject = node.getUserObject();
		if(userObject instanceof Host){
			setIcon(hostIcon);
		} else if(userObject instanceof Sentry){
			Sentry sentry = (Sentry)userObject;
			switch(sentry.getState()){
				case Sentry.NOT_TESTED:
					setIcon(trafficOffIcon);
					break;
				case Sentry.PASSED:
					setIcon(trafficGreenIcon);
					break;
				case Sentry.FAILED:
					setIcon(trafficRedIcon);
					break;
				case Sentry.TESTING:
					setIcon(clockIcon);
					break;
				default:
					break;
			}
		} else {
			if(expanded){
				setIcon(openFolderIcon);
			} else {
				setIcon(closedFolderIcon);
			}
		}
		
		return this;
	}
	
	private Icon openFolderIcon;
	private Icon closedFolderIcon;
	private Icon hostIcon;
	private Icon trafficOffIcon;
	private Icon trafficGreenIcon;
	private Icon trafficRedIcon;
	private Icon clockIcon;

}