/*-- 

 Copyright (C) 2000 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The names "J/Top" and "JTop" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "J/Top" or "JTop", nor
    may "J/Top" or "JTop" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by the
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on J/Top, please see <http://www.anthonyeden.com/projects/jtop>.
 
 */

package com.anthonyeden.jtop;

import java.io.*;
import java.util.*;
import org.jdom.*;
import org.jdom.input.*;
import org.jdom.output.*;
import com.anthonyeden.jtop.sentry.*;

public class SystemConfiguration{

	public SystemConfiguration(JTop parent, File file){
		this.parent = parent;
		this.file = file;
	}

	public void load() throws Exception{
		SAXBuilder builder = new SAXBuilder();
		Document document = builder.build(file);
		
		Element configElement = document.getRootElement();
		Namespace ns = configElement.getNamespace();
		Iterator i;
		
		// load host types
		
		i = configElement.getChildren("defineHost", ns).iterator();
		while(i.hasNext()){
			Element hostElement = (Element)i.next();
			HostManager.register(hostElement.getAttributeValue("name"), 
				hostElement.getAttributeValue("type"));
		}
		
		// load sentry configuration
		
		i = configElement.getChildren("defineSentry", ns).iterator();
		while(i.hasNext()){
			Element sentryElement = (Element)i.next();
			SentryManager.register(sentryElement.getAttributeValue("name"), 
				sentryElement.getAttributeValue("type"));
		}
		
		// load notifier configuration
		
		i = configElement.getChildren("defineNotifier", ns).iterator();
		while(i.hasNext()){
			Element sentryElement = (Element)i.next();
			NotifierManager.register(sentryElement.getAttributeValue("name"), 
				sentryElement.getAttributeValue("type"));
		}
		
		Element debugElement = configElement.getChild("debuggingAllowed", ns);
		if(debugElement != null){
			JTop.debuggingAllowed = true;
		}
		
	}
	
	public void save() throws Exception{
		XMLOutputter outputter = new XMLOutputter();
		outputter.setIndent("\t");
		outputter.setNewlines(true);
		
		Namespace ns = Namespace.getNamespace(Configuration.nsPrefix, Configuration.nsURL);
		Element configElement = new Element("config", ns);

		Enumeration sentryDefinitions = SentryManager.getNames().elements();
		while(sentryDefinitions.hasMoreElements()){
			String name = (String)sentryDefinitions.nextElement();
			Class type = SentryManager.getType(name);
			Element sentryDefinitionElement = new Element("defineSentry", ns);
			sentryDefinitionElement.addAttribute("name", name);
			sentryDefinitionElement.addAttribute("type", type.getName());
			
			configElement.addContent(sentryDefinitionElement);
		}
		
		Enumeration notifierDefinitions = NotifierManager.getNames().elements();
		while(notifierDefinitions.hasMoreElements()){
			String name = (String)notifierDefinitions.nextElement();
			Class type = NotifierManager.getType(name);
			Element notifierDefinitionElement = new Element("defineNotifier", ns);
			notifierDefinitionElement.addAttribute("name", name);
			notifierDefinitionElement.addAttribute("type", type.getName());
			
			configElement.addContent(notifierDefinitionElement);
		}
	}
	
	private JTop parent;
	private File file;
	
}