/*-- 

 Copyright (C) 2000 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The names "J/Top" and "JTop" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "J/Top" or "JTop", nor
    may "J/Top" or "JTop" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by the
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on J/Top, please see <http://www.anthonyeden.com/projects/jtop>.
 
 */

package com.anthonyeden.jtop.sentry;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import javax.swing.*;
import javax.swing.tree.*;
import com.anthonyeden.jtop.*;
import com.anthonyeden.jtop.event.*;

public class AllSentriesDialog extends JFrame implements SentryListener{

	public AllSentriesDialog(JTop parent){
		this.parent = parent;
		init();
		reloadTree();
	}
	
	public void sentryStateChanged(SentryEvent evt){
		TreeNode node = (TreeNode)getSentries().get(evt.getSentry());
		treeModel.nodeChanged(node);
	}
	
	protected void close(){
		Enumeration sentries = getSentries().keys();
		while(sentries.hasMoreElements()){
			((Sentry)sentries.nextElement()).removeSentryListener(this);
		}
		
		dispose();
	}
	
	protected void reloadTree(){
		rootNode.removeAllChildren();
	
		Enumeration hosts = parent.getHosts().list();
		while(hosts.hasMoreElements()){
			Host host = (Host)hosts.nextElement();
			DefaultMutableTreeNode hostNode = new DefaultMutableTreeNode(host);
			
			Enumeration sentries = host.getSentries().list();
			while(sentries.hasMoreElements()){
				Sentry sentry = (Sentry)sentries.nextElement();
				sentry.addSentryListener(this);
				DefaultMutableTreeNode sentryNode = new DefaultMutableTreeNode(sentry);
				getSentries().put(sentry, sentryNode);
				hostNode.add(sentryNode);
			}
			
			rootNode.add(hostNode);
		}
	}
	
	protected Hashtable getSentries(){
		if(sentries == null){
			sentries = new Hashtable();
		}
		return sentries;
	}
	
	private void init(){
		rootNode = new DefaultMutableTreeNode("Hosts");
		treeModel = new DefaultTreeModel(rootNode);
		hostTree = new JTree(treeModel);
		hostTree.putClientProperty("JTree.lineStyle", "Angled");
		hostTree.setCellRenderer(new HostTreeCellRenderer());
		
		getContentPane().setLayout(new BorderLayout());
		getContentPane().add(new JScrollPane(hostTree), "Center");
		getContentPane().add(createButtonPanel(), "South");
		
		setTitle("J/Top - All Hosts");
		pack();
	}
	
	private JPanel createButtonPanel(){
		JPanel panel = new JPanel();
		
		closeButton = new JButton("Close");
		closeButton.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent evt){
				close();
			}
		});
		panel.add(closeButton);
		
		return panel;
	}
	
	private JTop parent;
	private Hashtable sentries;
	private DefaultTreeModel treeModel;
	private DefaultMutableTreeNode rootNode;
	private JTree hostTree;
	private JButton closeButton;

}