/*-- 

 Copyright (C) 2000 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The names "J/Top" and "JTop" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "J/Top" or "JTop", nor
    may "J/Top" or "JTop" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by the
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on J/Top, please see <http://www.anthonyeden.com/projects/jtop>.
 
 */

package com.anthonyeden.jtop.sentry;

import java.awt.*;
import javax.swing.*;
import com.anthonyeden.jtop.*;

public class LimitSentryEditor extends JPanel implements Editor{

	public LimitSentryEditor(LimitSentry sentry){
		this.sentry = sentry;
		init();
	}
	
	public boolean save(){
		if(!verify()){
			return false;
		}
		
		sentry.setField(fieldCombo.getSelectedItem().toString());
		sentry.setName(nameField.getText());
		sentry.setLimit(Float.parseFloat(limitField.getText()));
		
		return true;
	}
	
	public void revert(){
		nameField.setText(sentry.getName());
		fieldCombo.setSelectedItem(sentry.getField());
		limitField.setText(Float.toString(sentry.getLimit()));
	}
	
	protected boolean verify(){
		Object selectedField = fieldCombo.getSelectedItem();
		if(selectedField == null){
			JOptionPane.showMessageDialog(null, "Please select a field", "Error", 
				JOptionPane.ERROR_MESSAGE);
			return false;
		}
		
		return true;
	}
	
	public Component getComponent(){
		return this;
	}
	
	private void init(){
		GridBagLayout gbl = new GridBagLayout();
		GridBagConstraints gbc = new GridBagConstraints();
		setLayout(gbl);
		
		gbc.insets = new Insets(1, 1, 1, 1);
		gbc.fill = GridBagConstraints.HORIZONTAL;
		
		nameLabel = new JLabel("Name:");
		gbc.weightx = 0;
		gbc.gridwidth = 1;
		gbl.setConstraints(nameLabel, gbc);
		add(nameLabel);
		
		nameField = new JTextField();
		nameField.setColumns(16);
		gbc.weightx = 1;
		gbc.gridwidth = GridBagConstraints.REMAINDER;
		gbl.setConstraints(nameField, gbc);
		add(nameField);
		
		fieldLabel = new JLabel("Field:");
		gbc.weightx = 0;
		gbc.gridwidth = 1;
		gbl.setConstraints(fieldLabel, gbc);
		add(fieldLabel);
		
		fieldCombo = new JComboBox(sentry.getHost().getFieldNames());
		gbc.weightx = 1;
		gbc.gridwidth = GridBagConstraints.REMAINDER;
		gbl.setConstraints(fieldCombo, gbc);
		add(fieldCombo);
		
		limitLabel = new JLabel("Limit:");
		gbc.weightx = 0;
		gbc.gridwidth = 1;
		gbl.setConstraints(limitLabel, gbc);
		add(limitLabel);
		
		limitField = new JTextField();
		limitField.setColumns(16);
		gbc.weightx = 1;
		gbc.gridwidth = GridBagConstraints.REMAINDER;
		gbl.setConstraints(limitField, gbc);
		add(limitField);
	}
	
	private LimitSentry sentry;
	private JLabel nameLabel;
	private JTextField nameField;
	private JLabel fieldLabel;
	private JComboBox fieldCombo;
	private JLabel limitLabel;
	private JTextField limitField;

}