/*-- 

 Copyright (C) 2000 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The names "J/Top" and "JTop" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "J/Top" or "JTop", nor
    may "J/Top" or "JTop" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by the
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on J/Top, please see <http://www.anthonyeden.com/projects/jtop>.
 
 */

package com.anthonyeden.jtop.sentry;

import java.util.*;
import javax.swing.*;
import javax.swing.event.*;

public class NotifierSet implements ListModel{

	public Enumeration list(){
		return getNotifiers().elements();
	}

	public synchronized void add(Notifier notifier){
		Vector notifiers = getNotifiers();
		int size = notifiers.size();
		if(!notifiers.contains(notifier)){
			notifiers.addElement(notifier);
			fireIntervalAdded(size, size);
		}
	}
	
	public synchronized void remove(Notifier notifier){
		Vector notifiers = getNotifiers();
		int index = notifiers.indexOf(notifier);
		if(index >= 0){
			notifiers.removeElementAt(index);
			fireIntervalRemoved(index, index);
		}
	}
	
	public synchronized void clear(){
		Vector notifiers = getNotifiers();
		int size = notifiers.size();
		notifiers.removeAllElements();
		fireIntervalRemoved(0, size);
	}

	public int getSize(){
		return getNotifiers().size();
	}
	
	public Object getElementAt(int index){
		return getNotifiers().elementAt(index);
	}
	
	public void addListDataListener(ListDataListener l){
		getListDataListeners().addElement(l);
	}
	
	public void removeListDataListener(ListDataListener l){
		getListDataListeners().removeElement(l);
	}
	
	// protected methods
	
	protected Vector getNotifiers(){
		if(notifiers == null){
			notifiers = new Vector();
		}
		return notifiers;
	}
	
	protected Vector getListDataListeners(){
		if(listDataListeners == null){
			listDataListeners = new Vector();
		}
		return listDataListeners;
	}
	
	protected void fireIntervalAdded(int start, int end){
		ListDataEvent evt = new ListDataEvent(this, ListDataEvent.INTERVAL_ADDED, 
			start, end);
		Vector v;
		
		synchronized(this){
			v = (Vector)(getListDataListeners().clone());
		}
		
		Enumeration l = v.elements();
		while(l.hasMoreElements()){
			((ListDataListener)l.nextElement()).intervalAdded(evt);
		}
	}
	
	protected void fireIntervalRemoved(int start, int end){
		ListDataEvent evt = new ListDataEvent(this, ListDataEvent.INTERVAL_REMOVED, 
			start, end);
		Vector v;
		
		synchronized(this){
			v = (Vector)(getListDataListeners().clone());
		}
		
		Enumeration l = v.elements();
		while(l.hasMoreElements()){
			((ListDataListener)l.nextElement()).intervalRemoved(evt);
		}
	}
	
	private Vector notifiers;
	private Vector listDataListeners;

}