/*-- 

 Copyright (C) 2000 Anthony Eden.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The names "J/Top" and "JTop" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact me@anthonyeden.com.
 
 4. Products derived from this software may not be called "J/Top" or "JTop", nor
    may "J/Top" or "JTop" appear in their name, without prior written permission
    from Anthony Eden (me@anthonyeden.com).
 
 In addition, I request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by the
      Anthony Eden (http://www.anthonyeden.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR(S) BE LIABLE FOR ANY DIRECT, 
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING 
 IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 POSSIBILITY OF SUCH DAMAGE.

 For more information on J/Top, please see <http://www.anthonyeden.com/projects/jtop>.
 
 */

package com.anthonyeden.jtop.sentry;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.anthonyeden.jtop.*;

public class SentriesPanel extends JPanel{

	public SentriesPanel(Host host){
		this.host = host;
		init();
	}
	
	public void editSentry(){
		Sentry sentry = (Sentry)sentryList.getSelectedValue();
		if(sentry != null){
			EditSentryDialog d = new EditSentryDialog(sentry);
			d.show();
		}
	}
	
	public void deleteSentry(){
		Sentry sentry = (Sentry)sentryList.getSelectedValue();
		if(sentry != null){
			if(JOptionPane.showConfirmDialog(null, 
				"Are you sure you want to remove the selected Sentry?", 
				"Are You Sure?", JOptionPane.YES_NO_OPTION) == 
				JOptionPane.YES_OPTION)
			{
				host.getSentries().remove((Sentry)sentryList.getSelectedValue());
			}
		}
	}
	
	private void init(){
		GridBagLayout gbl = new GridBagLayout();
		GridBagConstraints gbc = new GridBagConstraints();
		setLayout(gbl);
		
		gbc.insets = new Insets(1, 1, 1, 1);
		gbc.anchor = GridBagConstraints.NORTH;
		
		sentryList = new JList(host.getSentries());
		sentryList.setFixedCellWidth(100);
		sentryList.addMouseListener(new MouseAdapter(){
			public void mouseClicked(MouseEvent evt){
				if(evt.getClickCount() >= 2){
					editSentry();
				}
			}
		});
		JScrollPane scrollPane = new JScrollPane(sentryList);
		gbc.weightx = 1;
		gbc.weighty = 1;
		gbc.fill = GridBagConstraints.BOTH;
		gbc.gridwidth = 1;
		gbc.gridheight = GridBagConstraints.REMAINDER;
		gbl.setConstraints(scrollPane, gbc);
		add(scrollPane);
		
		gbc.weightx = 0;
		gbc.weighty = 0;
		gbc.fill = GridBagConstraints.HORIZONTAL;
		gbc.gridwidth = GridBagConstraints.REMAINDER;
		gbc.gridheight = 1;
		
		addSentryButton = new JButton("Add Sentry...");
		addSentryButton.setMnemonic('a');
		addSentryButton.setToolTipText("Create a new sentry");
		addSentryButton.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent evt){
				SelectSentryTypeDialog d = new SelectSentryTypeDialog(host);
				d.show();
			}
		});
		gbl.setConstraints(addSentryButton, gbc);
		add(addSentryButton);
		
		editSentryButton = new JButton("Edit Sentry...");
		editSentryButton.setToolTipText("Edit the selected sentry");
		editSentryButton.setMnemonic('e');
		editSentryButton.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent evt){
				editSentry();
			}
		});
		gbl.setConstraints(editSentryButton, gbc);
		add(editSentryButton);
		
		removeSentryButton = new JButton("Remove Sentry");
		removeSentryButton.setMnemonic('r');
		removeSentryButton.setToolTipText("Remove the selected sentry");
		removeSentryButton.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent evt){
				deleteSentry();
			}
		});
		gbl.setConstraints(removeSentryButton, gbc);
		gbc.weighty = 1;
		add(removeSentryButton);
	}
	
	private Host host;
	
	private JList sentryList;
	private JButton addSentryButton;
	private JButton editSentryButton;
	private JButton removeSentryButton;

}